@@ -1,5 +1,4 @@
 package Template::Plugin::PodGenerated;
-
 use strict;
 use warnings;
 use Class::ISA;
@@ -7,62 +6,49 @@ use Devel::Peek 'CvGV';
 use Devel::Symdump;
 use Pod::Generated 'doc';
 use Text::Conjunct;
-
-
-our $VERSION = '0.04';
-
-
+our $VERSION = '0.05';
 use base 'Template::Plugin';
 
-
 sub new {
     my ($class, $context) = @_;
-
     my $source = $context->stash->get('SOURCE');
-
     my $package;
     if ($source =~ /
         ^
         package \s*
         (\w+(::(?:\w+))*)
         \s* ;
-    /xms) {
+    /xms
+      ) {
         $package = $1;
     } else {
         die "can't parse package from source\n";
     }
 
     # This will generate documentation via add_doc.
-
     eval $source;
     die "can't eval source: $@\n" if $@;
 
-     # now that the source has been evaluated, we can look at the package
-     # variables.
- 
-     my $version;
-     {
-         no strict 'refs';
-         $version = ${ "${package}::VERSION" };
-     }
- 
-     bless {
-         _CONTEXT => $context,
-         package  => $package,
-         version  => $version,
+    # now that the source has been evaluated, we can look at the package
+    # variables.
+    my $version;
+    {
+        no strict 'refs';
+        $version = ${"${package}::VERSION"};
+    }
+    bless {
+        _CONTEXT => $context,
+        package  => $package,
+        version  => $version,
     }, $class;
 }
-
-
 sub package { $_[0]->{package} }
 sub version { $_[0]->{version} }
 
-
 sub format {
     my ($self, %args) = @_;
     my $result = '';
     my $line = my $indent = ' ' x $args{indent};
-
     for my $word (split /\s+/ => $args{text}) {
         if (length($line) + 1 + length($word) > $args{width}) {
             $result .= "$line\n";
@@ -76,10 +62,8 @@ sub format {
     $result;
 }
 
-
 # Heuristic: It's not a method if it has been imported from another package.
 # That is, if the glob is aliased to another package. CvGV() tells us that.
-
 sub is_not_method {
     my ($self, $function, $package) = @_;
     my $current = "${package}::${function}";
@@ -87,7 +71,6 @@ sub is_not_method {
     CvGV(*{$current}{CODE}) ne "*$current";
 }
 
-
 sub get_inheritance_data {
     my $self = shift;
 
@@ -96,14 +79,11 @@ sub get_inheritance_data {
     # lookup hash with the functions defined in the class that is being
     # documented, as we don't want to report those functions from the
     # inheritance.
-
     my %seen;
-    $seen{$_} = 1 for
-        map { s/^ $self->{package} :://x; $_ }
-        Devel::Symdump->new($self->{package})->functions;
-
+    $seen{$_} = 1
+      for map { s/^ $self->{package} :://x; $_ }
+      Devel::Symdump->new($self->{package})->functions;
     my @result;
-
     for my $package (Class::ISA::super_path($self->{package})) {
         my @functions;
         for my $function (Devel::Symdump->new($package)->functions) {
@@ -112,25 +92,22 @@ sub get_inheritance_data {
             next if $self->is_not_method($function, $package);
             push @functions => $function;
         }
-
         push @result => $package, [ $self->sub_order(@functions) ];
     }
     wantarray ? @result : \@result;
 }
 
-
 sub write_inheritance {
     my $self = shift;
     no strict 'refs';
     my @inherited = @{ $self->{package} . '::ISA' };
-
-    my $result = $self->format(
+    my $result    = $self->format(
         indent => 0,
         width  => 75,
-        text   => sprintf "%s inherits from %s.\n", $self->{package},
-            conjunct and => map { "L<$_>" } @inherited
+        text   => sprintf "%s inherits from %s.\n",
+        $self->{package},
+        conjunct and => map { "L<$_>" } @inherited
     );
-
     my @inheritance = $self->get_inheritance_data;
     while (my ($package, $functions) = splice(@inheritance, 0, 2)) {
         next unless @$functions;
@@ -138,84 +115,72 @@ sub write_inheritance {
         $result .= $self->format(
             indent => 0,
             width  => 75,
-            text   => "The superclass L<$package> defines these methods and functions:"
+            text =>
+              "The superclass L<$package> defines these methods and functions:"
         );
         $result .= "\n";
         $result .= $self->format(
             indent => 4,
             width  => 75,
-            text   =>
-                join ', ' =>
-                # map { "L<$_()|$package/$_>" }
-                map { "$_()" }
-                @$functions,
+            text   => join ', ' =>
+
+              # map { "L<$_()|$package/$_>" }
+              map { "$_()" } @$functions,
         );
     }
-
     1 while chomp $result;
     $result;
 }
 
-
 sub write_methods {
-    my $self = shift;
-
-    my %doc = doc();
+    my $self        = shift;
+    my %doc         = doc();
     my $package_doc = $doc{ $self->{package} }{CODE} || {};
-
-    my $result = '';
-
+    my $result      = '';
     for my $sub ($self->sub_order(keys %$package_doc)) {
         my $vars = {
             sub     => $sub,
             purpose => (join "\n" => @{ $package_doc->{$sub}{purpose} }),
-            example => (join "\n" => map { "    $_" } 
-                @{ $package_doc->{$sub}{example} }),
+            example => (
+                join "\n" => map { "    $_" } @{ $package_doc->{$sub}{example} }
+            ),
         };
-
         $result .=
-            "=item $vars->{sub}\n\n$vars->{example}\n\n$vars->{purpose}\n\n";
+          "=item $vars->{sub}\n\n$vars->{example}\n\n$vars->{purpose}\n\n";
     }
-
     1 while chomp $result;
     $result;
 }
 
-
 # Basically an alphabetic sort, but sort certain sub names first, such as
 # 'new' and 'instance'.
-
 sub sub_order {
     my ($self, @names) = @_;
-    
     my %has;
     @has{@names} = ();
 
     # partition the names into those that should come first, and the rest
     my @first;
-
     for my $name (qw(new instance)) {
         next unless exists $has{$name};
         delete $has{$name};
         push @first => $name;
     }
-
     (sort(@first), sort keys %has);
 }
-
-
 1;
+__END__
 
-
+=for test_synopsis
+1;
 __END__
 
 =head1 NAME
 
-{% p.package %} - Template plugin to help generate POD
+Template::Plugin::PodGenerated - Template plugin to help generate POD
 
 =head1 SYNOPSIS
 
-
     {% USE p = PodGenerated %}
 
     =head1 NAME
@@ -247,7 +212,7 @@ __END__
 This is a plugin for the L<Template> Toolkit that you can use to generate POD
 documentation during C<make> time.
 
-To understand the concepts behind this, please read the documetation of
+To understand the concepts behind this, please read the documentation of
 L<Module::Install::Template> and C<Pod::Generated>.
 
 When this plugin is loaded in a template - using C<USE p = PodGenerated>, for
@@ -261,19 +226,19 @@ This plugin provides the following methods to be used in templates:
 
 =over 4
 
-=item package
+=item C<package>
 
 The current package name as parsed from the source code.
 
-=item write_inheritance
+=item C<write_inheritance>
 
 Information about which classes the current class inherits from and which
-methods it inherites, as far as known. Only those methods in superclasses for
+methods it inherits, as far as known. Only those methods in superclasses for
 which documentation has also been generated are found through this mechanism.
 
 This might be improved at some point.
 
-=item write_methods
+=item C<write_methods>
 
 Write the documentation for the methods in the current package that have
 documentation defined for it.
@@ -282,7 +247,7 @@ documentation defined for it.
 
 =head1 TAGS
 
-If you talk about this module in blogs, on del.icio.us or anywhere else,
+If you talk about this module in blogs, on L<delicious.com> or anywhere else,
 please use the C<podgenerated> tag.
 
 =head1 BUGS AND LIMITATIONS
@@ -301,7 +266,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Pod-Generated/>.
 
 =head1 AUTHOR
 
@@ -309,7 +274,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2007-2009 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
